@@ -6,10 +6,10 @@ import os
 
 from TestToolsMK.collections_keywords import CollectionsKeywords
 from TestToolsMK.csv_keywords import CsvKeywords
-from TestToolsMK.image_magick_keywords import ImageMagickKeywords
+from TestToolsMK.image_pillow_keywords import ImagePillowKeywords
 from TestToolsMK.logger_extension_keywords import LoggerKeywords
-from TestToolsMK.selenium_extentions_keywords import SeleniumLibraryKeywords
-from TestToolsMK.sqlkeywords import SQLKeywords
+from TestToolsMK.selenium_extensions_keywords import ExtendedSeleniumLibrary
+from TestToolsMK.sql_keywords import SQLKeywords
 from TestToolsMK.timers_keywords import TimerKeywords
 from TestToolsMK.utils import UtilsKeywords
 
@@ -20,12 +20,14 @@ __version__ = open(__version_file_path__, "r").read().strip()
 class TestToolsMK(
     CollectionsKeywords,
     CsvKeywords,
-    ImageMagickKeywords,
+    ImagePillowKeywords,
     LoggerKeywords,
-    SeleniumLibraryKeywords,
+    ExtendedSeleniumLibrary,
     SQLKeywords,
     TimerKeywords,
     UtilsKeywords,
 ):
     ROBOT_LIBRARY_SCOPE = "GLOBAL"
-    ROBOT_LIBRARY_VERSION = __version__
+
+    def __init__(self):
+        pass
